==> oda-framework-0.1.73156.tgz: package/components/layouts/splitter/splitter.js <==
ODA({ is: 'oda-splitter',
    template: /*html*/`
    <style>
        :host([align=vertical]) {
            @apply --vertical;
            cursor: col-resize;
            width: {{size}}px;
            max-width: {{size}}px;
            min-width: {{size}}px;
            z-index: 1;
            position: relative;
        }
        :host([align=horizontal]) {
            @apply --horizontal;
            cursor: row-resize;
            height: {{size}}px;
            max-height: {{size}}px;
            min-height: {{size}}px;
        }
        :host([align=vertical])::after, :host([align=horizontal])::after, :host([align=vertical])::before, :host([align=horizontal])::before {
                position: absolute;
                content: "";
                z-index: 1;
                background: black;
                opacity: 0;
        }
        :host([align=vertical])::after, :host([align=vertical])::before {  top: 0; bottom: 0; width: {{10}}px;}
        :host([align=vertical])::after { left: 100%; }
        :host([align=vertical])::before { right: 100%; }
        :host([align=horizontal])::after, :host([align=horizontal])::before { left: 0; right: 0; height: {{pseudo}}px;}
        :host([align=horizontal])::after { top: 100%; }
        :host([align=horizontal])::before { bottom: 100%; }
        :host(:active) {
            z-index: 1;
            pointer-events: none;
        }
        :host {
            position: relative; 
            z-index: 1;
            background-color: {{color}};
            /*@apply --dark;*/
            overflow: visible;
            /*opacity: .3;*/
            transition: background-color .4s;
            align-items: center;
            justify-content: center;
            max-width: {{align === 'vertical' ? (+this.size >= 0 ? this.size + 'px' : '1px') : '100%'}};
            max-height: {{align === 'vertical' ? '100%' : (+this.size >= 0 ? this.size + 'px' : '1px')}};
        }

    </style>
    `,
    $public: {
        color: 'var(--dark-background)',
        size: 1,
        pseudo: 6,
        max: {
            $def: 0,
            $attr: true
        },
        align: {
            $def: 'vertical',
            $attr: true,
            $list: ['horizontal', 'vertical'],
        },
        reverse: false,
        width: {
            $type: Number,
            get() {
                return this.parent?.offsetWidth;
            },
            set(n) {
                if (this.max && n > this.max)
                    this.width = this.max;
            }
        },
        height: Number
    },
    sign: {
        $type: Number,
        $attr: true
    },
    get _sign() {
        if (this.sign) return this.sign;
        const items = [...(this.parent?.children || []), ...(this.parent?.$core?.root.children || [])];
        return (items.indexOf(this) === items.length - 1) ? -1 : 1
    },
    get parent() {
        return this.parentElement || this.domHost;
    },
    $listeners: {
        track: '_onTrack',
        pointerdown(e) {
            this._mover = ODA.createElement('oda-splitter-mover', { align: this.align });
            document.body.appendChild(this._mover);
        }
    },
    _onTrack(e, d) {
        switch (d.state) {
            case 'start': {
                this._mover.pos = d;
            } break;
            case 'end': {
                this._mover?.remove();
                switch (this.align) {
                    case 'horizontal': {
                        this.parent.style.height = this.parent.offsetHeight - d.dy * this._sign + 'px';
                    } break;
                    default: {
                        this.parent.style.width = this.parent.offsetWidth - d.dx * this._sign + 'px';
                    } break;
                }
            } break;
            case 'track': {
                switch (this.align) {
                    case 'horizontal': {
                        if (d.y >= 0 && d.y <= window.innerHeight) {
                            this._mover.pos = d;
                            this._mover.tracked = true;
                        }
                    } break;
                    default: {
                        if (d.x >= 0 && d.x <= window.innerWidth) {
                            this._mover.pos = d;
                            this._mover.tracked = true;
                        }
                    } break;
                }
            } break;
        }
    }
})

ODA({ is: 'oda-splitter-mover',
    template: /*html*/`
    <style>
        :host {
            position: fixed;
            width: 100%;
            height: 100%;
            animation: fadin 5s ease-in-out;
            background-color: rgba(0, 0, 0, 0.4);
            z-index: 1000;
            cursor: col-resize;
        }
        :host div {
            position: absolute;
            z-index: 1001;
            @apply --header;
        }
        @keyframes fadin {
            from {background-color: rgba(0, 0, 0, 0)}
            to {background-color: rgba(0, 0, 0, 0.4)}
        }
    </style>
    <div class="border" ~style="_getStyle(pos)"></div>
    `,
    align: '',
    pos: null,
    attached() {
        this.async(() => {
            this.style.setProperty?.('visibility', 'visible');
        })
    },
    $listeners: {
        mousedown(e) {
            this.remove();
        }
    },
    _getStyle(e) {
        if (e) {
            switch (this.align) {
                case 'vertical':
                    return `left:${(e.x - 2)}px; height: 100%; width: 2px; cursor: col-resize;`;
                case 'horizontal':
                    return `top:${(e.y - 2)}px; height: 2px; width: 100%; cursor: row-resize;`;
            }
        }
    }
})

==> oda-framework-0.1.73206.tgz: package/components/layouts/splitter/splitter.js <==
ODA({ is: 'oda-splitter',
    template: /*html*/`
    <style>
        :host([align=vertical]) {
            @apply --vertical;
            cursor: col-resize;
            width: {{size}}px;
            max-width: {{size}}px;
            min-width: {{size}}px;
            z-index: 1;
            position: relative;
        }
        :host([align=horizontal]) {
            @apply --horizontal;
            cursor: row-resize;
            height: {{size}}px;
            max-height: {{size}}px;
            min-height: {{size}}px;
        }
        :host([align=vertical])::after, :host([align=horizontal])::after, :host([align=vertical])::before, :host([align=horizontal])::before {
                position: absolute;
                content: "";
                z-index: 1;
                background: black;
                opacity: 0;
        }
        :host([align=vertical])::after, :host([align=vertical])::before {  top: 0; bottom: 0; width: {{pseudo}}px;}
        :host([align=vertical])::after { left: 100%; }
        :host([align=vertical])::before { right: 100%; }
        :host([align=horizontal])::after, :host([align=horizontal])::before { left: 0; right: 0; height: {{pseudo}}px;}
        :host([align=horizontal])::after { top: 100%; }
        :host([align=horizontal])::before { bottom: 100%; }
        :host(:active) {
            z-index: 1;
            pointer-events: none;
        }
        :host {
            position: relative; 
            z-index: 1;
            background-color: {{color}};
            /*@apply --dark;*/
            overflow: visible;
            /*opacity: .3;*/
            transition: background-color .4s;
            align-items: center;
            justify-content: center;
            max-width: {{align === 'vertical' ? (+this.size >= 0 ? this.size + 'px' : '1px') : '100%'}};
            max-height: {{align === 'vertical' ? '100%' : (+this.size >= 0 ? this.size + 'px' : '1px')}};
        }

    </style>
    `,
    $public: {
        color: 'var(--dark-background)',
        size: 1,
        pseudo: 4,
        max: {
            $def: 0,
            $attr: true
        },
        align: {
            $def: 'vertical',
            $attr: true,
            $list: ['horizontal', 'vertical'],
        },
        reverse: false,
        width: {
            $type: Number,
            get() {
                return this.parent?.offsetWidth;
            },
            set(n) {
                if (this.max && n > this.max)
                    this.width = this.max;
            }
        },
        height: Number
    },
    sign: {
        $type: Number,
        $attr: true
    },
    get _sign() {
        if (this.sign) return this.sign;
        const items = [...(this.parent?.children || []), ...(this.parent?.$core?.root.children || [])];
        return (items.indexOf(this) === items.length - 1) ? -1 : 1
    },
    get parent() {
        return this.parentElement || this.domHost;
    },
    $listeners: {
        track: '_onTrack',
        pointerdown(e) {
            this._mover = ODA.createElement('oda-splitter-mover', { align: this.align });
            document.body.appendChild(this._mover);
        }
    },
    _onTrack(e, d) {
        switch (d.state) {
            case 'start': {
                this._mover.pos = d;
            } break;
            case 'end': {
                this._mover?.remove();
                switch (this.align) {
                    case 'horizontal': {
                        this.parent.style.height = this.parent.offsetHeight - d.dy * this._sign + 'px';
                    } break;
                    default: {
                        this.parent.style.width = this.parent.offsetWidth - d.dx * this._sign + 'px';
                    } break;
                }
            } break;
            case 'track': {
                switch (this.align) {
                    case 'horizontal': {
                        if (d.y >= 0 && d.y <= window.innerHeight) {
                            this._mover.pos = d;
                            this._mover.tracked = true;
                        }
                    } break;
                    default: {
                        if (d.x >= 0 && d.x <= window.innerWidth) {
                            this._mover.pos = d;
                            this._mover.tracked = true;
                        }
                    } break;
                }
            } break;
        }
    }
})

ODA({ is: 'oda-splitter-mover',
    template: /*html*/`
    <style>
        :host {
            position: fixed;
            width: 100%;
            height: 100%;
            animation: fadin 5s ease-in-out;
            background-color: rgba(0, 0, 0, 0.4);
            z-index: 1000;
            cursor: col-resize;
        }
        :host div {
            position: absolute;
            z-index: 1001;
            @apply --header;
        }
        @keyframes fadin {
            from {background-color: rgba(0, 0, 0, 0)}
            to {background-color: rgba(0, 0, 0, 0.4)}
        }
    </style>
    <div class="border" ~style="_getStyle(pos)"></div>
    `,
    align: '',
    pos: null,
    attached() {
        this.async(() => {
            this.style.setProperty?.('visibility', 'visible');
        })
    },
    $listeners: {
        mousedown(e) {
            this.remove();
        }
    },
    _getStyle(e) {
        if (e) {
            switch (this.align) {
                case 'vertical':
                    return `left:${(e.x - 2)}px; height: 100%; width: 2px; cursor: col-resize;`;
                case 'horizontal':
                    return `top:${(e.y - 2)}px; height: 2px; width: 100%; cursor: row-resize;`;
            }
        }
    }
})
